/*  XFC: Xfce Foundation Classes (User Interface Library)
 *  Copyright (C) 2004 The XFC Development Team.
 *
 *  coverage.cc - PangoCoverage C++ wrapper implementation
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Library General Public License for more details.
 *
 *  You should have received a copy of the GNU Library General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */
 
#include "coverage.hh"

using namespace Xfc;

Pango::Coverage::Coverage()
: coverage_(pango_coverage_new())
{
}

Pango::Coverage::Coverage(PangoCoverage *coverage)
: coverage_(coverage)
{
	if (coverage_)
		pango_coverage_ref(coverage_);
}

Pango::Coverage::Coverage(const Coverage& src)
: coverage_(src.pango_coverage())
{
	if (coverage_)
		pango_coverage_ref(coverage_);
}

Pango::Coverage::~Coverage()
{
	if (coverage_)
	{
		pango_coverage_unref(coverage_);
		coverage_ = 0;
	}
}

Pango::Coverage&
Pango::Coverage::operator=(const Coverage& src)
{
	if (src.coverage_ == coverage_)
		return *this;

	if (coverage_)
		pango_coverage_unref(coverage_);

	coverage_ = src.coverage_;

	if (coverage_)
		pango_coverage_ref(coverage_);
	return *this;
}

Pointer<Pango::Coverage>
Pango::Coverage::from_bytes(unsigned char *bytes, int n_bytes)
{
	return new Coverage(pango_coverage_from_bytes(bytes, n_bytes));
}

void
Pango::Coverage::max(const Coverage& other)
{
	pango_coverage_max(pango_coverage(), other.pango_coverage());
}

